==> client-java-api-fluent-19.0.0-sources.jar: io/kubernetes/client/openapi/models/V1alpha1ValidatingAdmissionPolicyBindingListBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1alpha1ValidatingAdmissionPolicyBindingListBuilder extends V1alpha1ValidatingAdmissionPolicyBindingListFluentImpl<V1alpha1ValidatingAdmissionPolicyBindingListBuilder> implements VisitableBuilder<V1alpha1ValidatingAdmissionPolicyBindingList,V1alpha1ValidatingAdmissionPolicyBindingListBuilder>{
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder() {
    this(false);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(Boolean validationEnabled) {
    this(new V1alpha1ValidatingAdmissionPolicyBindingList(), validationEnabled);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent) {
    this(fluent, false);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1alpha1ValidatingAdmissionPolicyBindingList(), validationEnabled);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent,V1alpha1ValidatingAdmissionPolicyBindingList instance) {
    this(fluent, instance, false);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent,V1alpha1ValidatingAdmissionPolicyBindingList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingList instance) {
    this(instance,false);
  }
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent;
  Boolean validationEnabled;
  public V1alpha1ValidatingAdmissionPolicyBindingList build() {
    V1alpha1ValidatingAdmissionPolicyBindingList buildable = new V1alpha1ValidatingAdmissionPolicyBindingList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.getItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    return buildable;
  }
  
}

==> client-java-api-fluent-20.0.0-sources.jar: io/kubernetes/client/openapi/models/V1alpha1ValidatingAdmissionPolicyBindingListBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
public class V1alpha1ValidatingAdmissionPolicyBindingListBuilder extends V1alpha1ValidatingAdmissionPolicyBindingListFluent<V1alpha1ValidatingAdmissionPolicyBindingListBuilder> implements VisitableBuilder<V1alpha1ValidatingAdmissionPolicyBindingList,V1alpha1ValidatingAdmissionPolicyBindingListBuilder>{
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder() {
    this(new V1alpha1ValidatingAdmissionPolicyBindingList());
  }
  
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent) {
    this(fluent, new V1alpha1ValidatingAdmissionPolicyBindingList());
  }
  
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent,V1alpha1ValidatingAdmissionPolicyBindingList instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public V1alpha1ValidatingAdmissionPolicyBindingListBuilder(V1alpha1ValidatingAdmissionPolicyBindingList instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  V1alpha1ValidatingAdmissionPolicyBindingListFluent<?> fluent;
  
  public V1alpha1ValidatingAdmissionPolicyBindingList build() {
    V1alpha1ValidatingAdmissionPolicyBindingList buildable = new V1alpha1ValidatingAdmissionPolicyBindingList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.buildItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.buildMetadata());
    return buildable;
  }
  

}
